==> CGContentUtils-1.2.tar.gz: CGContentUtils/lang/ext/sk_SK.php <==
<?php
$lang['add_block'] = 'Pridať nov&yacute; blok';
$lang['advanced_content_copy'] = 'Roz&scaron;&iacute;ren&eacute; kop&iacute;rovanie obsahu';
$lang['advanced_copy'] = 'Roz&scaron;&iacute;ren&eacute; kop&iacute;rovanie';
$lang['ask_delete_block'] = 'Skutočne chcete odstr&aacute;niť tento blok?';
$lang['ask_really_uninstall'] = 'Ste si ist&yacute;?';
$lang['available_items'] = 'Dostupn&eacute; položky';
$lang['available_templates'] = 'Dostupn&yacute; k&oacute;d';
$lang['blocks'] = 'Bloky';
$lang['blocktype_textinput'] = 'Testov&eacute; pole';
$lang['blocktype_textarea'] = 'Textov&aacute; oblasť';
$lang['blocktype_dropdown'] = 'V&yacute;berov&eacute; pole';
$lang['blocktype_checkbox'] = 'Za&scaron;rt&aacute;vacie pole';
$lang['blocktype_pageselector'] = 'V&yacute;ber str&aacute;nok';
$lang['blocktype_radiobuttons'] = 'Radio tlač&iacute;tka';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['changelog'] = '<ul>
  <li>v1.0 - June 2009
    <ul>
      <li>Initial Relase</li>
    </ul>
  </li>
  <li>v1.0.2 - July 2010
    <ul>
      <li>Ability to perserve hierarchy when copying parents and children (Ted)</li>
      <li>Added check for prop copying to keep E_NOTICE happy (Ted)></li>
      <li>Minor change to sample tag info.</li>
      <li>Adds the page selector field type.</li>
    </ul>
  </li>
</ul>
TODO';
$lang['copy'] = 'Kop&iacute;rovať';
$lang['default_value'] = 'Prednastaven&aacute; hodnota';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['edit'] = 'Upraviť';
$lang['error_copycontent_invalid_name'] = 'N&aacute;zov pre kop&iacute;rovanie id=%d je neplatn&yacute;';
$lang['error_copycontent_invalid_menutext'] = 'N&aacute;zov v menu pre kop&iacute;rovanie id=%d je neplatn&yacute;';
$lang['error_missing_param'] = 'Požadovan&eacute; parametre su neplatn&eacute; alebo chyb&eacute;';
$lang['error_nameexists'] = 'Položka s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_nocontentselected'] = 'Nebol vybran&yacute; žiadny obsah';
$lang['error_permission_denied'] = 'Pr&iacute;stup  zamietnut&yacute;';
$lang['error_upload'] = 'Nahr&aacute;vanie s&uacute;bora s chybou';
$lang['export'] = 'Expotovať';
$lang['export_children'] = 'Exportovať podraden&eacute;';
$lang['export_code'] = 'Expportovať k&oacute;d';
$lang['export_content'] = 'Exportovať obsah';
$lang['extra'] = 'Extra ';
$lang['file'] = 'XML s&uacute;bor';
$lang['friendlyname'] = 'N&aacute;stroje pre pr&aacute;cu s obsahom';
$lang['help'] = '<h3>Čo modul rob&iacute;?</h3>
<p>Modul umožnuje pracovať s roz&scaron;&iacute;ren&yacute;mi funkciami pri pr&aacute;ci s obsahom.</p>
<h3>Funkcie</h3>
<ul>
  <li>Export obsahu do XML</li>
  <li>Import obsahu z XML</li>
  <li>Vytv&aacute;ranie obsahov&yacute; blokov do &scaron;abl&oacute;n.</li>
  <li>Hromadn&eacute; kop&iacute;rovanie str&aacute;nok.</li>
</ul>
<h3>How do I use it</h3>
<p>If you are an authorized CMS Made Simple web site administrator, and have sufficient privilege to manage all content, then the &amp;quit;Calguys Content Utilities&quot; menu item should appear in the CMS Made Simple administration panel.  You will see a number of tabs, including:</p>
<ul>
  <li><u>Blocks</u>
  <p>This tab provides functionality for creating &quot;named&quot; and managing content blocks of various types.  Tags for these content blocks can then be inserted into CMSMS page templates.  This provides functionality to put additonal content blocks into your page template to allow the user to enter or choose different data which may have a result on the appearance of the page.</p>
  <p>For example, a content block of type &quot;checkbox&quot; could be used to indicate wether an image is to be displayed or not.</p>
  <p>This is an advanced feature, and utilizing this feature requires that you be familiar with the smarty templating engine that is used througout CMSMS.</p>
  </li>
  <li><u>Import</u>
  <p>This tab provides the ability to import one or more content pages from an XML file that was created by the export functionality.   Using this functionality you can easily migrate information from one website to another.<p>
  </li>
  <li><u>Export</u>
  <p>This tab provides the ability to choose a single page from a dropdown to export to XML format.  You can also indicate wether the children of the selected page should be exported.  Clicking on the export button will prompt you to download the XML file.</p>
  <p>The generated XML file does not contain images, or page templates, or global content blocks, etc.  It only contains the contents of the various content objects, and their values.</p>
  </li>
</ul>
<p>Additionally, this module adds a bulk action to the content management page, which should be visible if you have the appropriate permission.  This bulk action allows selecting multiple pages, and creating a single copy of each of the selected pages,</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_available_items'] = 'Vyberte položky niž&scaron;ie pre export &scaron;abl&oacute;n alebo k&oacute;dov';
$lang['info_blockname'] = 'Použ&iacute;vajte iba alfanumerick&eacute; znaky, podčiarovn&iacute;ky a pomlčky';
$lang['info_blockprompt'] = '&Scaron;pecifikovať popisok';
$lang['info_dropdown_options'] = 'Vyberte položky pre v&yacute;berov&eacute; pole.  Jedna položka na každ&yacute; riadok.  Pre n&aacute;zov  a hodnotu položky oddelte hodnoty znakom |.';
$lang['import'] = 'Importovať';
$lang['import_code'] = 'Importovať k&oacute;d';
$lang['import_content'] = 'Importovať obsah';
$lang['list_gcbs'] = 'HTML bloky';
$lang['list_udts'] = 'Už&iacute;vateľsk&eacute; značky';
$lang['moddescription'] = 'Modul s n&aacute;strojami pre roz&scaron;&iacute;ren&uacute; spr&aacute;vu obsahu';
$lang['modules'] = 'Moduly';
$lang['msg_blockadded'] = 'Blok pridan&yacute;';
$lang['msg_blockupdated'] = 'Hodnoty  bloku aktualizovan&eacute;';
$lang['name'] = 'N&aacute;zov';
$lang['new_alias'] = 'Nov&yacute; alia';
$lang['new_menutext'] = 'Nov&yacute; n&aacute;zov v menu ';
$lang['new_name'] = 'Nov&yacute; n&aacute;zov';
$lang['new_parent'] = 'Nov&yacute; nadraden&yacute;';
$lang['parent'] = 'Nadraden&yacute;';
$lang['postinstall'] = 'Modul bol nain&scaron;talovan&yacute;';
$lang['postuninstall'] = 'Modul odin&scaron;talovan&yacute;';
$lang['prompt'] = 'Označenie, zobrazen&eacute; na str&aacute;nke';
$lang['prompt_cols'] = 'Stĺpce';
$lang['prompt_length'] = 'Dĺžka';
$lang['prompt_maxlength'] = 'Maxim&aacute;lna dĺžka';
$lang['prompt_options'] = 'Možnosti';
$lang['prompt_page'] = 'Str&aacute;nka';
$lang['prompt_rows'] = 'Riadky';
$lang['prompt_value'] = 'Hodnota';
$lang['scan'] = 'Skenovať';
$lang['start_page'] = '&Scaron;tartovacia str&aacute;nka';
$lang['submit'] = 'Odoslať';
$lang['type'] = 'Typ';
$lang['usage'] = 'Použitie';
$lang['xml_file'] = 'XML s&uacute;bor';
$lang['utma'] = '156861353.1423109725.1280259016.1283883395.1284147995.32';
$lang['utmz'] = '156861353.1284147995.32.30.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/873';
$lang['qca'] = 'P0-748439131-1280259017524';
$lang['utmb'] = '156861353.2.10.1284147995';
$lang['utmc'] = '156861353';
?>

==> CGContentUtils-1.3.tar.gz: CGContentUtils/lang/ext/sk_SK.php <==
<?php
$lang['add_block'] = 'Pridať nov&yacute; blok';
$lang['advanced_content_copy'] = 'Roz&scaron;&iacute;ren&eacute; kop&iacute;rovanie obsahu';
$lang['advanced_copy'] = 'Roz&scaron;&iacute;ren&eacute; kop&iacute;rovanie';
$lang['ask_delete_block'] = 'Skutočne chcete odstr&aacute;niť tento blok?';
$lang['ask_really_import'] = 'Ste si ist&yacute;, že chcete importovať tento k&oacute;d, napriek upozorneniam uveden&yacute;m vy&scaron;&scaron;ie';
$lang['ask_really_uninstall'] = 'Ste si ist&yacute;?';
$lang['available_items'] = 'Dostupn&eacute; položky';
$lang['available_templates'] = 'Dostupn&yacute; k&oacute;d';
$lang['blocks'] = 'Bloky';
$lang['blocktype_textinput'] = 'Testov&eacute; pole';
$lang['blocktype_textarea'] = 'Textov&aacute; oblasť';
$lang['blocktype_dropdown'] = 'V&yacute;berov&eacute; pole';
$lang['blocktype_checkbox'] = 'Za&scaron;rt&aacute;vacie pole';
$lang['blocktype_file_selector'] = 'V&yacute;berov&eacute; pole pre śubor';
$lang['blocktype_pageselector'] = 'V&yacute;ber str&aacute;nok';
$lang['blocktype_radiobuttons'] = 'Radio tlač&iacute;tka';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['changelog'] = '<ul>
  <li>v1.0 - June 2009
    <ul>
      <li>Initial Relase</li>
    </ul>
  </li>
  <li>v1.0.2 - July 2010
    <ul>
      <li>Ability to perserve hierarchy when copying parents and children (Ted)</li>
      <li>Added check for prop copying to keep E_NOTICE happy (Ted)></li>
      <li>Minor change to sample tag info.</li>
      <li>Adds the page selector field type.</li>
    </ul>
  </li>
</ul>
TODO';
$lang['content'] = 'Obsah';
$lang['contents_of_file'] = 'Naskenovan&eacute; obsahy s&uacute;bora';
$lang['copy'] = 'Kop&iacute;rovať';
$lang['default_value'] = 'Prednastaven&aacute; hodnota';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['edit'] = 'Upraviť';
$lang['error_broken_xml'] = 'XML s&uacute;bor je chybn&yacute;';
$lang['error_copycontent_invalid_name'] = 'N&aacute;zov pre kop&iacute;rovanie id=%d je neplatn&yacute;';
$lang['error_copycontent_invalid_menutext'] = 'N&aacute;zov v menu pre kop&iacute;rovanie id=%d je neplatn&yacute;';
$lang['error_missing_param'] = 'Požadovan&eacute; parametre su neplatn&eacute; alebo chyb&eacute;';
$lang['error_nameexists'] = 'Položka s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_nocontentselected'] = 'Nebol vybran&yacute; žiadny obsah';
$lang['error_notfound'] = 'Položka nen&aacute;jden&aacute;';
$lang['error_nothingtoimport'] = 'The XML file specified did not contain any information that could be imported into this installation (no compatible modules, or GCBs or UDTs)';
$lang['error_nothingselected'] = 'Neboli vybran&eacute; žiadne položky';
$lang['error_permission_denied'] = 'Pr&iacute;stup  zamietnut&yacute;';
$lang['error_upload'] = 'Nahr&aacute;vanie s&uacute;bora s chybou';
$lang['error_uploadnotfound'] = 'Nahr&aacute;van&yacute; s&uacute;bor nen&aacute;jden&yacute;';
$lang['export'] = 'Expotovať';
$lang['export_children'] = 'Exportovať podraden&eacute;';
$lang['export_code'] = 'Expportovať k&oacute;d';
$lang['export_content'] = 'Exportovať obsah';
$lang['extra'] = 'Extra ';
$lang['file'] = 'XML s&uacute;bor';
$lang['file_selector'] = 'V&yacute;ber s&uacute;borov';
$lang['friendlyname'] = 'N&aacute;stroje pre pr&aacute;cu s obsahom';
$lang['global_content_block'] = 'HTML bloky (GCB)';
$lang['help'] = '<h3>Čo modul rob&iacute;?</h3>
<p>Modul umožnuje pracovať s roz&scaron;&iacute;ren&yacute;mi funkciami pri pr&aacute;ci s obsahom.</p>
<h3>Funkcie</h3>
<ul>
  <li>Export obsahu do XML</li>
  <li>Import obsahu z XML</li>
  <li>Vytv&aacute;ranie obsahov&yacute; blokov do &scaron;abl&oacute;n.</li>
  <li>Hromadn&eacute; kop&iacute;rovanie str&aacute;nok.</li>
</ul>
<h3>How do I use it</h3>
<p>If you are an authorized CMS Made Simple web site administrator, and have sufficient privilege to manage all content, then the &amp;quit;Calguys Content Utilities&quot; menu item should appear in the CMS Made Simple administration panel.  You will see a number of tabs, including:</p>
<ul>
  <li><u>Blocks</u>
  <p>This tab provides functionality for creating &quot;named&quot; and managing content blocks of various types.  Tags for these content blocks can then be inserted into CMSMS page templates.  This provides functionality to put additonal content blocks into your page template to allow the user to enter or choose different data which may have a result on the appearance of the page.</p>
  <p>For example, a content block of type &quot;checkbox&quot; could be used to indicate wether an image is to be displayed or not.</p>
  <p>This is an advanced feature, and utilizing this feature requires that you be familiar with the smarty templating engine that is used througout CMSMS.</p>
  </li>
  <li><u>Import</u>
  <p>This tab provides the ability to import one or more content pages from an XML file that was created by the export functionality.   Using this functionality you can easily migrate information from one website to another.<p>
  </li>
  <li><u>Export</u>
  <p>This tab provides the ability to choose a single page from a dropdown to export to XML format.  You can also indicate wether the children of the selected page should be exported.  Clicking on the export button will prompt you to download the XML file.</p>
  <p>The generated XML file does not contain images, or page templates, or global content blocks, etc.  It only contains the contents of the various content objects, and their values.</p>
  </li>
</ul>
<p>Additionally, this module adds a bulk action to the content management page, which should be visible if you have the appropriate permission.  This bulk action allows selecting multiple pages, and creating a single copy of each of the selected pages,</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_available_items'] = 'Vyberte položky niž&scaron;ie pre export &scaron;abl&oacute;n alebo k&oacute;dov';
$lang['info_blockname'] = 'Použ&iacute;vajte iba alfanumerick&eacute; znaky, podčiarovn&iacute;ky a pomlčky';
$lang['info_blockprompt'] = '&Scaron;pecifikovať popisok';
$lang['info_dropdown_options'] = 'Vyberte položky pre v&yacute;berov&eacute; pole.  Jedna položka na každ&yacute; riadok.  Pre n&aacute;zov  a hodnotu položky oddelte hodnoty znakom |.';
$lang['info_excludeprefix'] = 'Exclude files with these prefixes (comma separated list)';
$lang['info_export_code'] = 'Export selected module templates, global content blocks, and module templates to an XML file for use on another web site';
$lang['info_filetypes'] = 'Specify a comma separated list of file extensions. i.e: pdf,jpg,doc';
$lang['info_final_import_code'] = 'The items selected for import  are be displayed below.  Items that represent an overwrite are hilighted in <span style=&quot;color: yellow;&quot;>yellow</span>. Please confirm that you really want to do this.<br/><strong>Note:</strong> It is possible by continuing that you may overwrite valid working templates.<br/>
<strong>Note:</strong> Some modules do not support multiple templates for each template type, therefore it may be necessary to overwrite some templates for them to have any effect.<br/>
<strong>Note:</strong> This module does not perform any modifications to the imported templates to check for references to pages, or existing module calls.  You may have to visit each template individually to customize its behavior for your site.';
$lang['info_import_code'] = 'Allows importing selected GBBs, UDTs and Module templates from an XML file.<br/><strong>Note:</strong> This is an advanced tool.  This feature allows overwriting templates into an existing syte.  Use with caution!';
$lang['info_scanned_file'] = 'Below are the scanned contents of the XML file supplied.  You may preview the items listed and select some for import.  You may optionally specify a new name for imported templates.';
$lang['import'] = 'Importovať';
$lang['import_code'] = 'Importovať k&oacute;d';
$lang['import_content'] = 'Importovať obsah';
$lang['import_name'] = 'N&aacute;zov importu';
$lang['list_gcbs'] = 'HTML bloky';
$lang['list_udts'] = 'Už&iacute;vateľsk&eacute; značky';
$lang['moddescription'] = 'Modul s n&aacute;strojami pre roz&scaron;&iacute;ren&uacute; spr&aacute;vu obsahu';
$lang['module'] = 'Modul';
$lang['modules'] = 'Moduly';
$lang['module_template'] = '&Scaron;abl&oacute;na modulu';
$lang['msg_blockadded'] = 'Blok pridan&yacute;';
$lang['msg_blockupdated'] = 'Hodnoty  bloku aktualizovan&eacute;';
$lang['msg_cancelled'] = 'Oper&aacute;cia zru&scaron;en&aacute;';
$lang['msg_imported'] = '%d položiek naimportovan&yacute;ch z XML';
$lang['name'] = 'N&aacute;zov';
$lang['new_alias'] = 'Nov&yacute; alias';
$lang['new_menutext'] = 'Nov&yacute; n&aacute;zov v menu ';
$lang['new_name'] = 'Nov&yacute; n&aacute;zov';
$lang['new_parent'] = 'Nov&yacute; nadraden&yacute;';
$lang['next'] = 'Ďal&scaron;&iacute;';
$lang['parent'] = 'Nadraden&yacute;';
$lang['postinstall'] = 'Modul bol nain&scaron;talovan&yacute;';
$lang['postuninstall'] = 'Modul odin&scaron;talovan&yacute;';
$lang['preview'] = 'N&aacute;hľad';
$lang['prompt'] = 'Označenie, zobrazen&eacute; na str&aacute;nke';
$lang['prompt_cols'] = 'Stĺpce';
$lang['prompt_dir'] = 'Adres&aacute;r <em>(relat&iacute;vna cesta k uploads adres&aacute;ru)</em>';
$lang['prompt_excludeprefix'] = 'Vynechať s&uacute;bory s t&yacute;mito predponami';
$lang['prompt_filetypes'] = 'Povolen&eacute; tipy s&uacute;borov';
$lang['prompt_length'] = 'Dĺžka';
$lang['prompt_maxlength'] = 'Maxim&aacute;lna dĺžka';
$lang['prompt_options'] = 'Možnosti';
$lang['prompt_page'] = 'Str&aacute;nka';
$lang['prompt_recurse'] = 'Rekurz&iacute;vne do podadres&aacute;rov';
$lang['prompt_rows'] = 'Riadky';
$lang['prompt_sortfiles'] = 'Triediť s&uacute;bory podľa mena';
$lang['prompt_value'] = 'Hodnota';
$lang['scan'] = 'Skenovať';
$lang['select_all'] = 'Vybrať v&scaron;etky';
$lang['start_page'] = '&Scaron;tartovacia str&aacute;nka';
$lang['submit'] = 'Odoslať';
$lang['type'] = 'Typ';
$lang['usage'] = 'Použitie';
$lang['userdefined_tag'] = 'Už&iacute;vateľsk&aacute; značka (UDT)';
$lang['xml_file'] = 'XML s&uacute;bor';
$lang['utma'] = '156861353.1888476224.1312573974.1312573974.1312573974.1';
$lang['utmz'] = '156861353.1312573974.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-1961957770-1309874446244';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
